@@ -150,6 +150,72 @@ func (p SHA512) FilterValue() string {
 	return p.Title()
 }
 
+// SHA224 encode string to sha224.
+type SHA224 struct{}
+
+func (p SHA224) Name() string {
+	return "SHA224"
+}
+
+func (p SHA224) Alias() []string {
+	return []string{"SHA224-sum"}
+}
+
+func (p SHA224) Transform(data []byte, _ ...Flag) (string, error) {
+	bs := sha256.Sum224(data)
+
+	return fmt.Sprintf("%x", bs), nil
+}
+
+func (p SHA224) Flags() []Flag {
+	return nil
+}
+
+func (p SHA224) Title() string {
+	return "SHA224 Sum"
+}
+
+func (p SHA224) Description() string {
+	return "Get the SHA224 checksum of your text"
+}
+
+func (p SHA224) FilterValue() string {
+	return p.Title()
+}
+
+// SHA224 encode string to sha224.
+type SHA384 struct{}
+
+func (p SHA384) Name() string {
+	return "SHA384"
+}
+
+func (p SHA384) Alias() []string {
+	return []string{"SHA384-sum"}
+}
+
+func (p SHA384) Transform(data []byte, _ ...Flag) (string, error) {
+	bs := sha512.Sum384(data)
+
+	return fmt.Sprintf("%x", bs), nil
+}
+
+func (p SHA384) Flags() []Flag {
+	return nil
+}
+
+func (p SHA384) Title() string {
+	return "SHA384 Sum"
+}
+
+func (p SHA384) Description() string {
+	return "Get the SHA384 checksum of your text"
+}
+
+func (p SHA384) FilterValue() string {
+	return p.Title()
+}
+
 // Bcrypt encode string to Bcrypt.
 type Bcrypt struct{}
 
