@@ -37,6 +37,8 @@ var List = []list.Item{
 	Kebab{},
 	Lower{},
 	Markdown{},
+	MorseCodeEncode{},
+	MorseCodeDecode{},
 	MD5{},
 	MSGPACKToJSON{},
 	RemoveNewLines{},
@@ -46,7 +48,9 @@ var List = []list.Item{
 	ReverseLines{},
 	ROT13Encode{},
 	SHA1{},
+	SHA224{},
 	SHA256{},
+	SHA384{},
 	SHA512{},
 	ShuffleLines{},
 	Slug{},
